@@ -5,9 +5,11 @@ import Data.GI.CodeGen.CabalHooks (setupBinding, TaggedOverride(..))
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "xlib"
         version = "2.0"
+        pkgName = "gi-xlib"
+        pkgVersion = "2.0.11"
         overridesFile = Just "xlib.overrides"
         verbose = False
         outputDir = Nothing
